Class: AWS::CloudFormation::StackEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/aws/cloud_formation/stack_event.rb

Overview

Stack Event

You can get stack events from a Stack object.

stack = cfm.stacks['stack-name']
stack.events.each do |event|
puts "#{event.timestamp}: #{event.resource_status}"
end

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(stack, details) ⇒ StackEvent

Returns a new instance of StackEvent.



30
31
32
33
34
35
# File 'lib/aws/cloud_formation/stack_event.rb', line 30

def initialize stack, details
  @stack = stack
  details.each_pair do |attr_name,attr_value|
    instance_variable_set("@#{attr_name}", attr_value)
  end
end

Instance Attribute Details

#event_id ⇒ String (readonly)

Returns event_id The unique ID of this event.

Returns:

  • (String) —

    event_id The unique ID of this event.



41
42
43
# File 'lib/aws/cloud_formation/stack_event.rb', line 41

def event_id
  @event_id
end

#logical_resource_id ⇒ String (readonly)

Returns The logical name of the resource specified in the template.

Returns:

  • (String) —

    The logical name of the resource specified in the template.



45
46
47
# File 'lib/aws/cloud_formation/stack_event.rb', line 45

def logical_resource_id
  @logical_resource_id
end

#physical_resource_id ⇒ String (readonly)

Returns The name or unique identifier associated with the physical instance of the resource.

Returns:

  • (String) —

    The name or unique identifier associated with the physical instance of the resource.



49
50
51
# File 'lib/aws/cloud_formation/stack_event.rb', line 49

def physical_resource_id
  @physical_resource_id
end

#resource_properties ⇒ String (readonly)

Returns BLOB of the properties used to create the resource.

Returns:

  • (String) —

    BLOB of the properties used to create the resource.



52
53
54
# File 'lib/aws/cloud_formation/stack_event.rb', line 52

def resource_properties
  @resource_properties
end

#resource_status ⇒ Symbol (readonly)

Returns Current status of the resource.

Returns:

  • (Symbol) —

    Current status of the resource.



55
56
57
# File 'lib/aws/cloud_formation/stack_event.rb', line 55

def resource_status
  @resource_status
end

#resource_status_reason ⇒ String? (readonly)

Returns Success/failure message associated with the resource.

Returns:

  • (String, nil) —

    Success/failure message associated with the resource.



59
60
61
# File 'lib/aws/cloud_formation/stack_event.rb', line 59

def resource_status_reason
  @resource_status_reason
end

#resource_type ⇒ String (readonly)

Returns Type of the resource (e.g. 'AWS::EC2::Instance').

Returns:

  • (String) —

    Type of the resource (e.g. 'AWS::EC2::Instance').



62
63
64
# File 'lib/aws/cloud_formation/stack_event.rb', line 62

def resource_type
  @resource_type
end

#stack ⇒ Stack (readonly)

Returns stack The stack this event belongs to.

Returns:

  • (Stack) —

    stack The stack this event belongs to.



38
39
40
# File 'lib/aws/cloud_formation/stack_event.rb', line 38

def stack
  @stack
end

#stack_id ⇒ String (readonly)

Returns The unique ID name of the instance of the stack.

Returns:

  • (String) —

    The unique ID name of the instance of the stack.



65
66
67
# File 'lib/aws/cloud_formation/stack_event.rb', line 65

def stack_id
  @stack_id
end

#stack_name ⇒ String (readonly)

Returns The name associated with a stack.

Returns:

  • (String) —

    The name associated with a stack.



68
69
70
# File 'lib/aws/cloud_formation/stack_event.rb', line 68

def stack_name
  @stack_name
end

#timestamp ⇒ Time (readonly)

Returns When the status was last updated.

Returns:

  • (Time) —

    When the status was last updated.



71
72
73
# File 'lib/aws/cloud_formation/stack_event.rb', line 71

def timestamp
  @timestamp
end