Method: AWS::EC2::NetworkACL::Entry#action

Defined in:
lib/aws/ec2/network_acl/entry.rb

#action:allow, :deny (readonly)

Returns Whether to allow or deny the traffic that matches the rule.

Returns:

  • (:allow, :deny)

    Whether to allow or deny the traffic that matches the rule.



52
53
54
# File 'lib/aws/ec2/network_acl/entry.rb', line 52

def action
  @action
end