Class: AWS::IAM::Client

Inherits:
Core::QueryClient show all
Defined in:
lib/aws/iam/client.rb

Overview

Client class for AWS Identity and Access Management (IAM).

Instance Attribute Summary

Attributes inherited from Core::Client

#config

Instance Method Summary collapse

Methods inherited from Core::Client

#initialize, #log_warning, #operations, operations, #with_http_handler, #with_options

Constructor Details

This class inherits a constructor from AWS::Core::Client

Instance Method Details

#add_role_to_instance_profile(options = {}) ⇒ Core::Response

Calls the AddRoleToInstanceProfile API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :instance_profile_name - required - (String) Name of the instance profile to update.
    • :role_name - required - (String) Name of the role to add.

Returns:



# File 'lib/aws/iam/client.rb', line 39


#add_user_to_group(options = {}) ⇒ Core::Response

Calls the AddUserToGroup API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :group_name - required - (String) Name of the group to update.
    • :user_name - required - (String) Name of the user to add.

Returns:



# File 'lib/aws/iam/client.rb', line 47


#change_password(options = {}) ⇒ Core::Response

Calls the ChangePassword API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :old_password - required - (String)
    • :new_password - required - (String)

Returns:



# File 'lib/aws/iam/client.rb', line 54


#create_access_key(options = {}) ⇒ Core::Response

Calls the CreateAccessKey API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - (String) The user name that the new key will belong to.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :access_key - (Hash)
      • :user_name - (String)
      • :access_key_id - (String)
      • :status - (String)
      • :secret_access_key - (String)
      • :create_date - (Time)


# File 'lib/aws/iam/client.rb', line 61


#create_account_alias(options = {}) ⇒ Core::Response

Calls the CreateAccountAlias API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :account_alias - required - (String) Name of the account alias to create.

Returns:



# File 'lib/aws/iam/client.rb', line 77


#create_group(options = {}) ⇒ Core::Response

Calls the CreateGroup API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :path - (String) The path to the group. For more information about paths, see Identifiers for IAM Entities in Using AWS Identity and Access Management. This parameter is optional. If it is not included, it defaults to a slash (/).
    • :group_name - required - (String) Name of the group to create. Do not include the path in this value.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :group - (Hash)
      • :path - (String)
      • :group_name - (String)
      • :group_id - (String)
      • :arn - (String)
      • :create_date - (Time)


# File 'lib/aws/iam/client.rb', line 84


#create_instance_profile(options = {}) ⇒ Core::Response

Calls the CreateInstanceProfile API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :instance_profile_name - required - (String) Name of the instance profile to create.
    • :path - (String) The path to the instance profile. For more information about paths, see Identifiers for IAM Entities in Using AWS Identity and Access Management. This parameter is optional. If it is not included, it defaults to a slash (/).

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :instance_profile - (Hash)
      • :path - (String)
      • :instance_profile_name - (String)
      • :instance_profile_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :roles - (Array)
      • :path - (String)
      • :role_name - (String)
      • :role_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :assume_role_policy_document - (String)


# File 'lib/aws/iam/client.rb', line 104


#create_login_profile(options = {}) ⇒ Core::Response

Calls the CreateLoginProfile API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) Name of the user to create a password for.
    • :password - required - (String) The new password for the user name.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :login_profile - (Hash)
      • :user_name - (String)
      • :create_date - (Time)


# File 'lib/aws/iam/client.rb', line 131


#create_role(options = {}) ⇒ Core::Response

Calls the CreateRole API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :path - (String) The path to the role. For more information about paths, see Identifiers for IAM Entities in Using AWS Identity and Access Management. This parameter is optional. If it is not included, it defaults to a slash (/).
    • :role_name - required - (String) Name of the role to create.
    • :assume_role_policy_document - required - (String) The policy that grants an entity permission to assume the role.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :role - (Hash)
      • :path - (String)
      • :role_name - (String)
      • :role_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :assume_role_policy_document - (String)


# File 'lib/aws/iam/client.rb', line 146


#create_user(options = {}) ⇒ Core::Response

Calls the CreateUser API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :path - (String) The path for the user name. For more information about paths, see Identifiers for IAM Entities in Using AWS Identity and Access Management. This parameter is optional. If it is not included, it defaults to a slash (/).
    • :user_name - required - (String) Name of the user to create.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :user - (Hash)
      • :path - (String)
      • :user_name - (String)
      • :user_id - (String)
      • :arn - (String)
      • :create_date - (Time)


# File 'lib/aws/iam/client.rb', line 168


#create_virtual_mfa_device(options = {}) ⇒ Core::Response

Calls the CreateVirtualMFADevice API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :path - (String) The path for the virtual MFA device. For more information about paths, see Identifiers for IAM Entities in Using AWS Identity and Access Management. This parameter is optional. If it is not included, it defaults to a slash (/).
    • :virtual_mfa_device_name - required - (String) The name of the virtual MFA device. Use with path to uniquely identify a virtual MFA device.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :virtual_mfa_device - (Hash)
      • :serial_number - (String)
      • :base_32_string_seed - (String)
      • :qr_code_png - (String)
      • :user - (Hash)
      • :path - (String)
      • :user_name - (String)
      • :user_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :enable_date - (Time)


# File 'lib/aws/iam/client.rb', line 187


#deactivate_mfa_device(options = {}) ⇒ Core::Response

Calls the DeactivateMFADevice API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) Name of the user whose MFA device you want to deactivate.
    • :serial_number - required - (String) The serial number that uniquely identifies the MFA device. For virtual MFA devices, the serial number is the device ARN.

Returns:



# File 'lib/aws/iam/client.rb', line 213


#delete_access_key(options = {}) ⇒ Core::Response

Calls the DeleteAccessKey API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - (String) Name of the user whose key you want to delete.
    • :access_key_id - required - (String) The Access Key ID for the Access Key ID and Secret Access Key you want to delete.

Returns:



# File 'lib/aws/iam/client.rb', line 223


#delete_account_alias(options = {}) ⇒ Core::Response

Calls the DeleteAccountAlias API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :account_alias - required - (String) Name of the account alias to delete.

Returns:



# File 'lib/aws/iam/client.rb', line 232


#delete_account_password_policy(options = {}) ⇒ Core::Response

Calls the DeleteAccountPasswordPolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})

Returns:



# File 'lib/aws/iam/client.rb', line 239


#delete_group(options = {}) ⇒ Core::Response

Calls the DeleteGroup API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :group_name - required - (String) Name of the group to delete.

Returns:



# File 'lib/aws/iam/client.rb', line 244


#delete_group_policy(options = {}) ⇒ Core::Response

Calls the DeleteGroupPolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :group_name - required - (String) Name of the group the policy is associated with.
    • :policy_name - required - (String) Name of the policy document to delete.

Returns:



# File 'lib/aws/iam/client.rb', line 250


#delete_instance_profile(options = {}) ⇒ Core::Response

Calls the DeleteInstanceProfile API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :instance_profile_name - required - (String) Name of the instance profile to delete.

Returns:



# File 'lib/aws/iam/client.rb', line 259


#delete_login_profile(options = {}) ⇒ Core::Response

Calls the DeleteLoginProfile API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) Name of the user whose password you want to delete.

Returns:



# File 'lib/aws/iam/client.rb', line 266


#delete_role(options = {}) ⇒ Core::Response

Calls the DeleteRole API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :role_name - required - (String) Name of the role to delete.

Returns:



# File 'lib/aws/iam/client.rb', line 273


#delete_role_policy(options = {}) ⇒ Core::Response

Calls the DeleteRolePolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :role_name - required - (String) Name of the role the associated with the policy.
    • :policy_name - required - (String) Name of the policy document to delete.

Returns:



# File 'lib/aws/iam/client.rb', line 279


#delete_server_certificate(options = {}) ⇒ Core::Response

Calls the DeleteServerCertificate API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :server_certificate_name - required - (String) The name of the server certificate you want to delete.

Returns:



# File 'lib/aws/iam/client.rb', line 288


#delete_signing_certificate(options = {}) ⇒ Core::Response

Calls the DeleteSigningCertificate API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - (String) Name of the user the signing certificate belongs to.
    • :certificate_id - required - (String) ID of the signing certificate to delete.

Returns:



# File 'lib/aws/iam/client.rb', line 295


#delete_user(options = {}) ⇒ Core::Response

Calls the DeleteUser API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) Name of the user to delete.

Returns:



# File 'lib/aws/iam/client.rb', line 304


#delete_user_policy(options = {}) ⇒ Core::Response

Calls the DeleteUserPolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) Name of the user the policy is associated with.
    • :policy_name - required - (String) Name of the policy document to delete.

Returns:



# File 'lib/aws/iam/client.rb', line 310


#delete_virtual_mfa_device(options = {}) ⇒ Core::Response

Calls the DeleteVirtualMFADevice API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :serial_number - required - (String) The serial number that uniquely identifies the MFA device. For virtual MFA devices, the serial number is the same as the ARN.

Returns:



# File 'lib/aws/iam/client.rb', line 319


#enable_mfa_device(options = {}) ⇒ Core::Response

Calls the EnableMFADevice API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) Name of the user for whom you want to enable the MFA device.
    • :serial_number - required - (String) The serial number that uniquely identifies the MFA device. For virtual MFA devices, the serial number is the device ARN.
    • :authentication_code_1 - required - (String) An authentication code emitted by the device.
    • :authentication_code_2 - required - (String) A subsequent authentication code emitted by the device.

Returns:



# File 'lib/aws/iam/client.rb', line 327


#get_account_password_policy(options = {}) ⇒ Core::Response

Calls the GetAccountPasswordPolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :password_policy - (Hash)
      • :minimum_password_length - (Integer)
      • :require_symbols - (Boolean)
      • :require_numbers - (Boolean)
      • :require_uppercase_characters - (Boolean)
      • :require_lowercase_characters - (Boolean)
      • :allow_users_to_change_password - (Boolean)


# File 'lib/aws/iam/client.rb', line 341


#get_account_summary(options = {}) ⇒ Core::Response

Calls the GetAccountSummary API operation.

Parameters:

  • options (Hash) (defaults to: {})

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :summary_map - (Hash)


# File 'lib/aws/iam/client.rb', line 356


#get_group(options = {}) ⇒ Core::Response

Calls the GetGroup API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :group_name - required - (String) Name of the group.
    • :marker - (String) Use this only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this only when paginating results to indicate the maximum number of user names you want in the response. If there are additional user names beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :group - (Hash)
      • :path - (String)
      • :group_name - (String)
      • :group_id - (String)
      • :arn - (String)
      • :create_date - (Time)
    • :users - (Array)
      • :path - (String)
      • :user_name - (String)
      • :user_id - (String)
      • :arn - (String)
      • :create_date - (Time)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 365


#get_group_policy(options = {}) ⇒ Core::Response

Calls the GetGroupPolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :group_name - required - (String) Name of the group the policy is associated with.
    • :policy_name - required - (String) Name of the policy document to get.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :group_name - (String)
    • :policy_name - (String)
    • :policy_document - (String)


# File 'lib/aws/iam/client.rb', line 396


#get_instance_profile(options = {}) ⇒ Core::Response

Calls the GetInstanceProfile API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :instance_profile_name - required - (String) Name of the instance profile to get information about.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :instance_profile - (Hash)
      • :path - (String)
      • :instance_profile_name - (String)
      • :instance_profile_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :roles - (Array)
      • :path - (String)
      • :role_name - (String)
      • :role_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :assume_role_policy_document - (String)


# File 'lib/aws/iam/client.rb', line 411


#get_login_profile(options = {}) ⇒ Core::Response

Calls the GetLoginProfile API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) Name of the user whose login profile you want to retrieve.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :login_profile - (Hash)
      • :user_name - (String)
      • :create_date - (Time)


# File 'lib/aws/iam/client.rb', line 434


#get_role(options = {}) ⇒ Core::Response

Calls the GetRole API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :role_name - required - (String) Name of the role to get information about.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :role - (Hash)
      • :path - (String)
      • :role_name - (String)
      • :role_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :assume_role_policy_document - (String)


# File 'lib/aws/iam/client.rb', line 447


#get_role_policy(options = {}) ⇒ Core::Response

Calls the GetRolePolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :role_name - required - (String) Name of the role associated with the policy.
    • :policy_name - required - (String) Name of the policy document to get.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :role_name - (String)
    • :policy_name - (String)
    • :policy_document - (String)


# File 'lib/aws/iam/client.rb', line 464


#get_server_certificate(options = {}) ⇒ Core::Response

Calls the GetServerCertificate API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :server_certificate_name - required - (String) The name of the server certificate you want to retrieve information about.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :server_certificate - (Hash)
      • :server_certificate_metadata - (Hash)
      • :path - (String)
      • :server_certificate_name - (String)
      • :server_certificate_id - (String)
      • :arn - (String)
      • :upload_date - (Time)
      • :certificate_body - (String)
      • :certificate_chain - (String)


# File 'lib/aws/iam/client.rb', line 479


#get_user(options = {}) ⇒ Core::Response

Calls the GetUser API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - (String) Name of the user to get information about. This parameter is optional. If it is not included, it defaults to the user making the request.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :user - (Hash)
      • :path - (String)
      • :user_name - (String)
      • :user_id - (String)
      • :arn - (String)
      • :create_date - (Time)


# File 'lib/aws/iam/client.rb', line 498


#get_user_policy(options = {}) ⇒ Core::Response

Calls the GetUserPolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) Name of the user who the policy is associated with.
    • :policy_name - required - (String) Name of the policy document to get.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :user_name - (String)
    • :policy_name - (String)
    • :policy_document - (String)


# File 'lib/aws/iam/client.rb', line 515


#list_access_keys(options = {}) ⇒ Core::Response

Calls the ListAccessKeys API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - (String) Name of the user.
    • :marker - (String) Use this parameter only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this parameter only when paginating results to indicate the maximum number of keys you want in the response. If there are additional keys beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :access_key_metadata - (Array)
      • :user_name - (String)
      • :access_key_id - (String)
      • :status - (String)
      • :create_date - (Time)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 530


#list_account_aliases(options = {}) ⇒ Core::Response

Calls the ListAccountAliases API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :marker - (String) Use this only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this only when paginating results to indicate the maximum number of account aliases you want in the response. If there are additional account aliases beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :account_aliases - (Array)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 554


#list_group_policies(options = {}) ⇒ Core::Response

Calls the ListGroupPolicies API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :group_name - required - (String) The name of the group to list policies for.
    • :marker - (String) Use this only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this only when paginating results to indicate the maximum number of policy names you want in the response. If there are additional policy names beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :policy_names - (Array)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 573


#list_groups(options = {}) ⇒ Core::Response

Calls the ListGroups API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :path_prefix - (String) The path prefix for filtering the results. For example: /division_abc/subdivision_xyz/, which would get all groups whose path starts with /division_abc/subdivision_xyz/. This parameter is optional. If it is not included, it defaults to a slash (/), listing all groups.
    • :marker - (String) Use this only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this only when paginating results to indicate the maximum number of groups you want in the response. If there are additional groups beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :groups - (Array)
      • :path - (String)
      • :group_name - (String)
      • :group_id - (String)
      • :arn - (String)
      • :create_date - (Time)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 594


#list_groups_for_user(options = {}) ⇒ Core::Response

Calls the ListGroupsForUser API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) The name of the user to list groups for.
    • :marker - (String) Use this only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this only when paginating results to indicate the maximum number of groups you want in the response. If there are additional groups beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :groups - (Array)
      • :path - (String)
      • :group_name - (String)
      • :group_id - (String)
      • :arn - (String)
      • :create_date - (Time)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 623


#list_instance_profiles(options = {}) ⇒ Core::Response

Calls the ListInstanceProfiles API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :path_prefix - (String) The path prefix for filtering the results. For example: /application_abc/component_xyz/, which would get all instance profiles whose path starts with /application_abc/component_xyz/. This parameter is optional. If it is not included, it defaults to a slash (/), listing all instance profiles.
    • :marker - (String) Use this parameter only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this parameter only when paginating results to indicate the maximum number of user names you want in the response. If there are additional user names beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :instance_profiles - (Array)
      • :path - (String)
      • :instance_profile_name - (String)
      • :instance_profile_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :roles - (Array)
      • :path - (String)
      • :role_name - (String)
      • :role_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :assume_role_policy_document - (String)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 649


#list_instance_profiles_for_role(options = {}) ⇒ Core::Response

Calls the ListInstanceProfilesForRole API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :role_name - required - (String) The name of the role to list instance profiles for.
    • :marker - (String) Use this parameter only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this parameter only when paginating results to indicate the maximum number of user names you want in the response. If there are additional user names beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :instance_profiles - (Array)
      • :path - (String)
      • :instance_profile_name - (String)
      • :instance_profile_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :roles - (Array)
      • :path - (String)
      • :role_name - (String)
      • :role_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :assume_role_policy_document - (String)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 686


#list_mfa_devices(options = {}) ⇒ Core::Response

Calls the ListMFADevices API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - (String) Name of the user whose MFA devices you want to list.
    • :marker - (String) Use this only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this only when paginating results to indicate the maximum number of MFA devices you want in the response. If there are additional MFA devices beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :mfa_devices - (Array)
      • :user_name - (String)
      • :serial_number - (String)
      • :enable_date - (Time)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 719


#list_role_policies(options = {}) ⇒ Core::Response

Calls the ListRolePolicies API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :role_name - required - (String) The name of the role to list policies for.
    • :marker - (String) Use this parameter only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this parameter only when paginating results to indicate the maximum number of user names you want in the response. If there are additional user names beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :policy_names - (Array)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 743


#list_roles(options = {}) ⇒ Core::Response

Calls the ListRoles API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :path_prefix - (String) The path prefix for filtering the results. For example: /application_abc/component_xyz/, which would get all roles whose path starts with /application_abc/component_xyz/. This parameter is optional. If it is not included, it defaults to a slash (/), listing all roles.
    • :marker - (String) Use this parameter only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this parameter only when paginating results to indicate the maximum number of user names you want in the response. If there are additional user names beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :roles - (Array)
      • :path - (String)
      • :role_name - (String)
      • :role_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :assume_role_policy_document - (String)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 764


#list_server_certificates(options = {}) ⇒ Core::Response

Calls the ListServerCertificates API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :path_prefix - (String) The path prefix for filtering the results. For example: /company/servercerts would get all server certificates for which the path starts with /company/servercerts. This parameter is optional. If it is not included, it defaults to a slash (/), listing all server certificates.
    • :marker - (String) Use this only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this only when paginating results to indicate the maximum number of server certificates you want in the response. If there are additional server certificates beyond the maximum you specify, the IsTruncated response element will be set to true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :server_certificate_metadata_list - (Array)
      • :path - (String)
      • :server_certificate_name - (String)
      • :server_certificate_id - (String)
      • :arn - (String)
      • :upload_date - (Time)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 794


#list_signing_certificates(options = {}) ⇒ Core::Response

Calls the ListSigningCertificates API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - (String) The name of the user.
    • :marker - (String) Use this only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this only when paginating results to indicate the maximum number of certificate IDs you want in the response. If there are additional certificate IDs beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :certificates - (Array)
      • :user_name - (String)
      • :certificate_id - (String)
      • :certificate_body - (String)
      • :status - (String)
      • :upload_date - (Time)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 824


#list_user_policies(options = {}) ⇒ Core::Response

Calls the ListUserPolicies API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) The name of the user to list policies for.
    • :marker - (String) Use this only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this only when paginating results to indicate the maximum number of policy names you want in the response. If there are additional policy names beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :policy_names - (Array)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 849


#list_users(options = {}) ⇒ Core::Response

Calls the ListUsers API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :path_prefix - (String) The path prefix for filtering the results. For example: /division_abc/subdivision_xyz/, which would get all user names whose path starts with /division_abc/subdivision_xyz/. This parameter is optional. If it is not included, it defaults to a slash (/), listing all user names.
    • :marker - (String) Use this parameter only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this parameter only when paginating results to indicate the maximum number of user names you want in the response. If there are additional user names beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :users - (Array)
      • :path - (String)
      • :user_name - (String)
      • :user_id - (String)
      • :arn - (String)
      • :create_date - (Time)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 870


#list_virtual_mfa_devices(options = {}) ⇒ Core::Response

Calls the ListVirtualMFADevices API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :assignment_status - (String) The status (unassigned or assigned) of the devices to list. If you do not specify an AssignmentStatus, the action defaults to Any which lists both assigned and unassigned virtual MFA devices. Valid values include:
      • Assigned
      • Unassigned
      • Any
    • :marker - (String) Use this parameter only when paginating results, and only in a subsequent request after you've received a response where the results are truncated. Set it to the value of the Marker element in the response you just received.
    • :max_items - (Integer) Use this parameter only when paginating results to indicate the maximum number of user names you want in the response. If there are additional user names beyond the maximum you specify, the IsTruncated response element is true .

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :virtual_mfa_devices - (Array)
      • :serial_number - (String)
      • :base_32_string_seed - (String)
      • :qr_code_png - (String)
      • :user - (Hash)
      • :path - (String)
      • :user_name - (String)
      • :user_id - (String)
      • :arn - (String)
      • :create_date - (Time)
      • :enable_date - (Time)
    • :is_truncated - (Boolean)
    • :marker - (String)


# File 'lib/aws/iam/client.rb', line 900


#put_group_policy(options = {}) ⇒ Core::Response

Calls the PutGroupPolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :group_name - required - (String) Name of the group to associate the policy with.
    • :policy_name - required - (String) Name of the policy document.
    • :policy_document - required - (String) The policy document.

Returns:



# File 'lib/aws/iam/client.rb', line 936


#put_role_policy(options = {}) ⇒ Core::Response

Calls the PutRolePolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :role_name - required - (String) Name of the role to associate the policy with.
    • :policy_name - required - (String) Name of the policy document.
    • :policy_document - required - (String) The policy document.

Returns:



# File 'lib/aws/iam/client.rb', line 945


#put_user_policy(options = {}) ⇒ Core::Response

Calls the PutUserPolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) Name of the user to associate the policy with.
    • :policy_name - required - (String) Name of the policy document.
    • :policy_document - required - (String) The policy document.

Returns:



# File 'lib/aws/iam/client.rb', line 954


#remove_role_from_instance_profile(options = {}) ⇒ Core::Response

Calls the RemoveRoleFromInstanceProfile API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :instance_profile_name - required - (String) Name of the instance profile to update.
    • :role_name - required - (String) Name of the role to remove.

Returns:



# File 'lib/aws/iam/client.rb', line 963


#remove_user_from_group(options = {}) ⇒ Core::Response

Calls the RemoveUserFromGroup API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :group_name - required - (String) Name of the group to update.
    • :user_name - required - (String) Name of the user to remove.

Returns:



# File 'lib/aws/iam/client.rb', line 971


#resync_mfa_device(options = {}) ⇒ Core::Response

Calls the ResyncMFADevice API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) Name of the user whose MFA device you want to resynchronize.
    • :serial_number - required - (String) Serial number that uniquely identifies the MFA device.
    • :authentication_code_1 - required - (String) An authentication code emitted by the device.
    • :authentication_code_2 - required - (String) A subsequent authentication code emitted by the device.

Returns:



# File 'lib/aws/iam/client.rb', line 978


#update_access_key(options = {}) ⇒ Core::Response

Calls the UpdateAccessKey API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - (String) Name of the user whose key you want to update.
    • :access_key_id - required - (String) The Access Key ID of the Secret Access Key you want to update.
    • :status - required - (String) The status you want to assign to the Secret Access Key. Active means the key can be used for API calls to AWS, while Inactive means the key cannot be used. Valid values include:
      • Active
      • Inactive

Returns:



# File 'lib/aws/iam/client.rb', line 991


#update_account_password_policy(options = {}) ⇒ Core::Response

Calls the UpdateAccountPasswordPolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :minimum_password_length - (Integer)
    • :require_symbols - (Boolean)
    • :require_numbers - (Boolean)
    • :require_uppercase_characters - (Boolean)
    • :require_lowercase_characters - (Boolean)
    • :allow_users_to_change_password - (Boolean)

Returns:



# File 'lib/aws/iam/client.rb', line 1006


#update_assume_role_policy(options = {}) ⇒ Core::Response

Calls the UpdateAssumeRolePolicy API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :role_name - required - (String) Name of the role to update.
    • :policy_document - required - (String) The policy that grants an entity permission to assume the role.

Returns:



# File 'lib/aws/iam/client.rb', line 1017


#update_group(options = {}) ⇒ Core::Response

Calls the UpdateGroup API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :group_name - required - (String) Name of the group to update. If you're changing the name of the group, this is the original name.
    • :new_path - (String) New path for the group. Only include this if changing the group's path.
    • :new_group_name - (String) New name for the group. Only include this if changing the group's name.

Returns:



# File 'lib/aws/iam/client.rb', line 1025


#update_login_profile(options = {}) ⇒ Core::Response

Calls the UpdateLoginProfile API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) Name of the user whose password you want to update.
    • :password - (String) The new password for the user name.

Returns:



# File 'lib/aws/iam/client.rb', line 1037


#update_server_certificate(options = {}) ⇒ Core::Response

Calls the UpdateServerCertificate API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :server_certificate_name - required - (String) The name of the server certificate that you want to update.
    • :new_path - (String) The new path for the server certificate. Include this only if you are updating the server certificate's path.
    • :new_server_certificate_name - (String) The new name for the server certificate. Include this only if you are updating the server certificate's name.

Returns:



# File 'lib/aws/iam/client.rb', line 1045


#update_signing_certificate(options = {}) ⇒ Core::Response

Calls the UpdateSigningCertificate API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - (String) Name of the user the signing certificate belongs to.
    • :certificate_id - required - (String) The ID of the signing certificate you want to update.
    • :status - required - (String) The status you want to assign to the certificate. Active means the certificate can be used for API calls to AWS, while Inactive means the certificate cannot be used. Valid values include:
      • Active
      • Inactive

Returns:



# File 'lib/aws/iam/client.rb', line 1058


#update_user(options = {}) ⇒ Core::Response

Calls the UpdateUser API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - required - (String) Name of the user to update. If you're changing the name of the user, this is the original user name.
    • :new_path - (String) New path for the user. Include this parameter only if you're changing the user's path.
    • :new_user_name - (String) New name for the user. Include this parameter only if you're changing the user's name.

Returns:



# File 'lib/aws/iam/client.rb', line 1073


#upload_server_certificate(options = {}) ⇒ Core::Response

Calls the UploadServerCertificate API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :path - (String) The path for the server certificate. For more information about paths, see Identifiers for IAM Entities in Using AWS Identity and Access Management. This parameter is optional. If it is not included, it defaults to a slash (/).
    • :server_certificate_name - required - (String) The name for the server certificate. Do not include the path in this value.
    • :certificate_body - required - (String) The contents of the public key certificate in PEM-encoded format.
    • :private_key - required - (String) The contents of the private key in PEM-encoded format.
    • :certificate_chain - (String) The contents of the certificate chain. This is typically a concatenation of the PEM-encoded public key certificates of the chain.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :server_certificate_metadata - (Hash)
      • :path - (String)
      • :server_certificate_name - (String)
      • :server_certificate_id - (String)
      • :arn - (String)
      • :upload_date - (Time)


# File 'lib/aws/iam/client.rb', line 1085


#upload_signing_certificate(options = {}) ⇒ Core::Response

Calls the UploadSigningCertificate API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :user_name - (String) Name of the user the signing certificate is for.
    • :certificate_body - required - (String) The contents of the signing certificate.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :certificate - (Hash)
      • :user_name - (String)
      • :certificate_id - (String)
      • :certificate_body - (String)
      • :status - (String)
      • :upload_date - (Time)


# File 'lib/aws/iam/client.rb', line 1112