Class: AWS::Support::Client

Inherits:
Core::JSONClient show all
Defined in:
lib/aws/support/client.rb

Overview

Client class for AWS Support.

Instance Attribute Summary

Attributes inherited from Core::Client

#config

Instance Method Summary collapse

Methods inherited from Core::Client

#initialize, #log_warning, #operations, operations, #with_http_handler, #with_options

Constructor Details

This class inherits a constructor from AWS::Core::Client

Instance Method Details

#add_communication_to_case(options = {}) ⇒ Core::Response

Calls the AddCommunicationToCase API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :case_id - (String)
    • :communication_body - required - (String)
    • :cc_email_addresses - (Array)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :result - (Boolean)


# File 'lib/aws/support/client.rb', line 25


#create_case(options = {}) ⇒ Core::Response

Calls the CreateCase API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :subject - required - (String)
    • :service_code - required - (String)
    • :severity_code - (String)
    • :category_code - required - (String)
    • :communication_body - required - (String)
    • :cc_email_addresses - (Array)
    • :language - (String)
    • :issue_type - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :case_id - (String)


# File 'lib/aws/support/client.rb', line 36


#describe_cases(options = {}) ⇒ Core::Response

Calls the DescribeCases API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :case_id_list - (Array)
    • :display_id - (String)
    • :after_time - (String)
    • :before_time - (String)
    • :include_resolved_cases - (Boolean)
    • :next_token - (String)
    • :max_results - (Integer)
    • :language - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :cases - (Array)
      • :case_id - (String)
      • :display_id - (String)
      • :subject - (String)
      • :status - (String)
      • :service_code - (String)
      • :category_code - (String)
      • :severity_code - (String)
      • :submitted_by - (String)
      • :time_created - (String)
      • :recent_communications - (Hash)
      • :communications - (Array)
        • :case_id - (String)
        • :body - (String)
        • :submitted_by - (String)
        • :time_created - (String)
      • :next_token - (String)
      • :cc_email_addresses - (Array)
      • :language - (String)
    • :next_token - (String)


# File 'lib/aws/support/client.rb', line 52


#describe_communications(options = {}) ⇒ Core::Response

Calls the DescribeCommunications API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :case_id - required - (String)
    • :before_time - (String)
    • :after_time - (String)
    • :next_token - (String)
    • :max_results - (Integer)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :communications - (Array)
      • :case_id - (String)
      • :body - (String)
      • :submitted_by - (String)
      • :time_created - (String)
    • :next_token - (String)


# File 'lib/aws/support/client.rb', line 87


#describe_services(options = {}) ⇒ Core::Response

Calls the DescribeServices API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :service_code_list - (Array)
    • :language - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :services - (Array)
      • :code - (String)
      • :name - (String)
      • :categories - (Array)
      • :code - (String)
      • :name - (String)


# File 'lib/aws/support/client.rb', line 105


#describe_severity_levels(options = {}) ⇒ Core::Response

Calls the DescribeSeverityLevels API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :language - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :severity_levels - (Array)
      • :code - (String)
      • :name - (String)


# File 'lib/aws/support/client.rb', line 120


#describe_trusted_advisor_check_refresh_statuses(options = {}) ⇒ Core::Response

Calls the DescribeTrustedAdvisorCheckRefreshStatuses API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :check_ids - required - (Array)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :statuses - (Array)
      • :check_id - (String)
      • :status - (String)
      • :millis_until_next_refreshable - (Integer)


# File 'lib/aws/support/client.rb', line 131


#describe_trusted_advisor_check_result(options = {}) ⇒ Core::Response

Calls the DescribeTrustedAdvisorCheckResult API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :check_id - required - (String)
    • :language - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :result - (Hash)
      • :check_id - (String)
      • :timestamp - (String)
      • :status - (String)
      • :resources_summary - (Hash)
      • :resources_processed - (Integer)
      • :resources_flagged - (Integer)
      • :resources_ignored - (Integer)
      • :resources_suppressed - (Integer)
      • :category_specific_summary - (Hash)
      • :cost_optimizing - (Hash)
        • :estimated_monthly_savings - (Numeric)
        • :estimated_percent_monthly_savings - (Numeric)
      • :flagged_resources - (Array)
      • :status - (String)
      • :region - (String)
      • :resource_id - (String)
      • :is_suppressed - (Boolean)
      • :metadata - (Array)


# File 'lib/aws/support/client.rb', line 143


#describe_trusted_advisor_check_summaries(options = {}) ⇒ Core::Response

Calls the DescribeTrustedAdvisorCheckSummaries API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :check_ids - required - (Array)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :summaries - (Array)
      • :check_id - (String)
      • :timestamp - (String)
      • :status - (String)
      • :has_flagged_resources - (Boolean)
      • :resources_summary - (Hash)
      • :resources_processed - (Integer)
      • :resources_flagged - (Integer)
      • :resources_ignored - (Integer)
      • :resources_suppressed - (Integer)
      • :category_specific_summary - (Hash)
      • :cost_optimizing - (Hash)
        • :estimated_monthly_savings - (Numeric)
        • :estimated_percent_monthly_savings - (Numeric)


# File 'lib/aws/support/client.rb', line 171


#describe_trusted_advisor_checks(options = {}) ⇒ Core::Response

Calls the DescribeTrustedAdvisorChecks API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :language - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :checks - (Array)
      • :id - (String)
      • :name - (String)
      • :description - (String)
      • :category - (String)
      • :metadata - (Array)


# File 'lib/aws/support/client.rb', line 193


#refresh_trusted_advisor_check(options = {}) ⇒ Core::Response

Calls the RefreshTrustedAdvisorCheck API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :check_id - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :status - (Hash)
      • :check_id - (String)
      • :status - (String)
      • :millis_until_next_refreshable - (Integer)


# File 'lib/aws/support/client.rb', line 207


#resolve_case(options = {}) ⇒ Core::Response

Calls the ResolveCase API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :case_id - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :initial_case_status - (String)
    • :final_case_status - (String)


# File 'lib/aws/support/client.rb', line 219